@@ -3,6 +3,7 @@ import pytest
 import ckan.plugins as p
 import ckan.lib.search.query as query
 
+from ckanext.search_tweaks import CONFIG_PREFER_BOOST
 import ckanext.search_tweaks.plugin as plugin
 
 
@@ -17,25 +18,26 @@ class TestPlugin:
         assert search()["defType"] == "edismax"
         assert search(defType="dismax")["defType"] == "dismax"
 
+    @pytest.mark.ckan_config(CONFIG_PREFER_BOOST, "no")
     def test_default_bf(self, search):
         assert search()["bf"] == "0"
 
+    @pytest.mark.ckan_config(CONFIG_PREFER_BOOST, "no")
     def test_modified_bf(self, search):
         result = search(bf="sum(0,1)")
         assert result["bf"] == "sum(0,1)"
         assert "boost" not in result
 
-    def test_boost_is_not_used_by_defautl(self, search):
+    @pytest.mark.ckan_config(CONFIG_PREFER_BOOST, "no")
+    def test_boost_is_disabled(self, search):
         assert "boost" not in search()
 
-    @pytest.mark.ckan_config(plugin.CONFIG_PREFER_BOOST, "yes")
-    def test_boost_enabled_and_empty(self, search):
+    def test_boost_enabled_by_default_and_empty(self, search):
         result = search()
         assert "bf" not in result
         assert result["boost"] == []
 
-    @pytest.mark.ckan_config(plugin.CONFIG_PREFER_BOOST, "yes")
-    def test_boost_enabled_and_modified(self, search):
+    def test_boost_modified(self, search):
         result = search(boost=["0", "1"])
         assert "bf" not in result
         assert result["boost"] == ["0", "1"]
